source ~/.vimrc

lua << EOF
-- require("nvim-lsp-installer").setup {
--     automatic_installation = true
-- }
require('impatient')
require('orgmode').setup_ts_grammar()

local nvim_lsp = require('lspconfig')
local lsp_extensions = require('lsp_extensions')

lsp_extensions.inlay_hints{
	highlight = "Comment",
	prefix = " > ",
	aligned = false,
	only_current_line = false,
	enabled = { "ChainingHint" }
}

require('colorizer').setup{}
require('feline').setup{}
require('bufferline').setup{}

require('nvim-treesitter.configs').setup {
  highlight = {
    enable = true,
    additional_vim_regex_highlighting = {'org'},
  },
  ensure_installed = {'org'},
}

require('orgmode').setup({
  org_agenda_files = {'~/Documents/**/*'},
  org_default_notes_file = '~/Sync/General/Dokumente/default.org',
})

local servers = { 'html', 'clangd', 'vimls', 'vuels', 'phpactor', 'rust_analyzer', 'rome', 'pyright', 'svelte', 'cssls', 'texlab'}

local on_attach = function (client, bufnr)
    local function buf_set_keymap(...) vim.api.nvim_buf_set_keymap(bufnr, ...) end
    local function buf_set_option(...) vim.api.nvim_buf_set_option(bufnr, ...) end

    -- Mappings.
    local opts = { noremap=true, silent=true }

    -- See `:help vim.lsp.*` for documentation on any of the below functions
    buf_set_keymap('n', 'gD', '<cmd>lua vim.lsp.buf.declaration()<CR>', opts)
    buf_set_keymap('n', 'gd', '<cmd>lua vim.lsp.buf.definition()<CR>', opts)
    buf_set_keymap('n', 'K', '<cmd>lua vim.lsp.buf.hover()<CR>', opts)
    buf_set_keymap('n', 'gi', '<cmd>lua vim.lsp.buf.implementation()<CR>', opts)
    buf_set_keymap('n', '<C-k>', '<cmd>lua vim.lsp.buf.signature_help()<CR>', opts)
    buf_set_keymap('n', '<space>D', '<cmd>lua vim.lsp.buf.type_definition()<CR>', opts)
    buf_set_keymap('n', '<space>rn', '<cmd>lua vim.lsp.buf.rename()<CR>', opts)
    buf_set_keymap('n', '<space>ca', '<cmd>lua vim.lsp.buf.code_action()<CR>', opts)
    buf_set_keymap('n', 'gr', '<cmd>lua vim.lsp.buf.references()<CR>', opts)
    buf_set_keymap('n', '=', '<cmd>lua vim.lsp.buf.formatting()<CR>', opts)
end

-- local coq = require('coq')
for _, lsp in ipairs(servers) do
    -- nvim_lsp[lsp].setup(coq.lsp_ensure_capabilities({
    --     on_attach = on_attach,
    --     flags = {
    --         debounce_text_changes = 150,
    --     }
    -- }))

    nvim_lsp[lsp].setup({
        on_attach = on_attach,
        flags = {
            debounce_text_changes = 150,
        }
    })
end

EOF
